@@ -4,7 +4,7 @@ from PyQt5.QtWidgets import QMainWindow
 # import warnings
 import numpy as np
 import matplotlib
-from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
+from matplotlib.backends.backend_qtagg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.figure import Figure
 import math
 
@@ -38,8 +38,9 @@ x_chapter = 560
 
 
 class NNDLayout(QMainWindow):
-    def __init__(self, w_ratio, h_ratio, dpi, chapter_window=True, main_menu=False, draw_vertical=True, print_mouse_coords=False,
-                 fixed_size=False, do_not_scale=False):
+    def __init__(self, w_ratio, h_ratio, dpi, chapter_window=True, main_menu=False, draw_vertical=True,
+                 draw_horizontal=True, print_mouse_coords=False, fixed_size=False, do_not_scale=False,
+                 overwrite_size=None):
 
         super(NNDLayout, self).__init__()
 
@@ -64,6 +65,8 @@ class NNDLayout(QMainWindow):
             self.setFixedSize(WM_MAC_CHAPTER, HM_MAC_CHAPTER)
         else:
             self.setFixedSize(self.wm, self.hm)
+        if overwrite_size is not None:
+            self.setFixedSize(overwrite_size[0] * w_ratio, overwrite_size[1] * h_ratio)
         self.center()
 
         size_scaled = int(10 * (self.w_ratio + self.h_ratio) / 2)
@@ -79,6 +82,7 @@ class NNDLayout(QMainWindow):
         self.label3, self.label4, self.label5, self.icon1, self.icon2 = None, None, None, None, None
 
         self.draw_vertical = draw_vertical
+        self.draw_horizontal = draw_horizontal
         if main_menu == 1:
             self.setWindowTitle("Neural Network Design Demos")
             self.make_label("label1", "Neural Network", (xlabel, ylabel, wlabel, hlabel), font_size=18, italics=True)
@@ -98,11 +102,12 @@ class NNDLayout(QMainWindow):
         qp.end()
 
     def draw_lines(self, qp):
-        pen = QtGui.QPen(QtCore.Qt.darkBlue, 4, QtCore.Qt.SolidLine)
-        qp.setPen(pen)
-        # qp.drawLine(xl1 * self.w_ratio, yl1 * self.h_ratio, self.wm - xl1 * self.w_ratio, yl1 * self.h_ratio)
-        qp.drawLine(xl1 * self.w_ratio, yl1 * self.h_ratio, xl2 * self.w_ratio, yl1 * self.h_ratio)
-        qp.drawLine(xl3 * self.w_ratio, yl4 * self.h_ratio, xl4 * self.w_ratio, yl4 * self.h_ratio)
+        if self.draw_horizontal:
+            pen = QtGui.QPen(QtCore.Qt.darkBlue, 4, QtCore.Qt.SolidLine)
+            qp.setPen(pen)
+            # qp.drawLine(xl1 * self.w_ratio, yl1 * self.h_ratio, self.wm - xl1 * self.w_ratio, yl1 * self.h_ratio)
+            qp.drawLine(xl1 * self.w_ratio, yl1 * self.h_ratio, xl2 * self.w_ratio, yl1 * self.h_ratio)
+            qp.drawLine(xl3 * self.w_ratio, yl4 * self.h_ratio, xl4 * self.w_ratio, yl4 * self.h_ratio)
 
         if self.draw_vertical:
             pen = QtGui.QPen(QtCore.Qt.darkBlue, 4, QtCore.Qt.SolidLine)
@@ -356,10 +361,12 @@ class NNDLayout(QMainWindow):
         self.set_layout(checkbox_coords, checkbox)
         checkbox.setChecked(1 if checked else 0)
 
-    def make_input_box(self, input_box_attr_name, input_box_text, input_box_coords):
+    def make_input_box(self, input_box_attr_name, input_box_text, input_box_coords, func_text_changed=None):
         setattr(self, input_box_attr_name, QtWidgets.QLineEdit())
         input_box = getattr(self, input_box_attr_name)
         input_box.setText(input_box_text)
+        if func_text_changed is not None:
+            input_box.textChanged[str].connect(func_text_changed)
         # font = input_box.font()
         # font.setPointSize(int(20 * (self.w_ratio + self.h_ratio) / 2))
         # input_box.setFont(font)
